==> todotask2.0.1.zip: todotask2/app/views/grp/list.php <==
<?php
	// ページ描画
	// ヘッダ
	require_once(TODOTASK_VIEW_DIR.'/common/header.inc.php');

	$aryGrpList = $this->aryGrpList;

	$task_state = "";
	if ($this->mode==GRP_CLASS_MODE_MYGRP) {
		$task_state = "参加グループ";
		$mytag_img = "mytask.png";
		$alltag_img = "alltask2.png";
	} else {
		$task_state = "グループ一覧";
		$mytag_img = "mytask2.png";
		$alltag_img = "alltask.png";
	}

	// タスクのリンクを作成する
	function fSetTaskList($group_no,$group_name,$group_note,$aryassent,$aryview,$upd,$group_prio) {
		if ( $group_no =="" ) {
			return true;
		}
?>
		<p><a href="./tasklist.php?group_no=<?php echo $group_no; ?>"><span class="grptitle">
		■ <?php echo $group_name; ?></span></a>
		(<?php echo $upd; ?>)
		グループ重要度：<?php echo $group_prio;?>
		<small><?php echo $aryview;?> / <?php echo $aryassent; ?></small><br>
		<span class="grpnote">
		<?php echo $group_note;?>
		<br></span></p>		

<?php
	}
?>





<div style="margin:auto;padding:auto;text-align:center;">
<img src="./images/whytodotask.png" alt="タスクや障害を詳細に分解しリストにすることはあなたを目標から遠ざけないただひとつの吸引力！" border="0">
</div>
<div class="noticediv">
このサービスはやるべきこと(TO-DO)や課せられた仕事(TASK)をリスト化するのに便利です。<br>
備忘録や業務の進捗管理などにも使えます。
TODOTASKの<big><a href="<?php echo INFO_HOWTOUSE_PAGE; ?>" target="_blank">使用ガイド</a></big>をごらんください。
</div>
<br clear="both">


<div style="border-bottom:solid 3px #000000;margin-bottom:10px;">
<a href="./index.php?mode=<?php echo GRP_CLASS_MODE_MYGRP;?>">
<img src="./images/<?php echo $mytag_img; ?>" alt="自分のグループのみ表示する" border="0" align="left"></a>
<a href="./index.php?mode=<?php echo GRP_CLASS_MODE_LIST;?>">
<img src="./images/<?php echo $alltag_img; ?>" alt="すべてのグループを表示する" border="0"></a>
</div>


<?php
if ($this->mode==GRP_CLASS_MODE_MYGRP) {
?>
<a href="./grpmake.php"><img src="./images/btn_makegroup.png" alt="新規グループの作成" border="0" align="right"></a><br><br>
<?php
}
?>

<h4><?php echo $task_state; ?></h4>
<div class="grplist">
<?php
	// グループリンクの表示
	for( $i=0; $i < count($aryGrpList); $i++ ) {
		// タスクのリンク
		fSetTaskList($aryGrpList[$i]["group_no"],
					$aryGrpList[$i]["group_name"],
					$aryGrpList[$i]["group_note"],
					$aryGrpList[$i]["assent"],
					$aryGrpList[$i]["view"],
					$aryGrpList[$i]["upd"],
					$aryGrpList[$i]["group_prio"]);
	} 

	if (count($aryGrpList)==0) {
		echo "<br>参加グループはありません。既存のグループに参加するか自分のタスクグループを作成してください。<br>" .
				"既存のグループはAll Taskボタンから表示できます。<br><br>";
	}


// 改ページの表示
?>
	</div><br>
	<div class="pagelink">
	<?php echo $this->pagelink; ?>
	</div><br><br>



<div style="text-align:right;width:100%;">
<?php
if ($this->user_id == "") {
?>
<div style="width:450px;border:solid #eeddee 2px;padding:10px;background-color:#ffffff;right:0px;float:right;">
<a href="./usermst.php"><img src="./images/btn_signup.png" alt="新規ユーザー登録" border="0"></a><br>

ログインされていません。このサービスを利用するにはユーザー登録後にログインをしていただく必要があります。<br>
ユーザー登録は上のボタンをクリックして必要な情報を入力してください。<br>

<?php
	// 外部認証が利用できる場合
	if (JUGEM_AUTHFLG||HATENA_AUTHFLG||LIVEDOOR_AUTHFLG) {
?>
<hr size="1">
<big>外部認証が利用できるように設定されています。</big><br>
Hatena,LiveDoor,Jugemなど他のサービスでログインしている場合ユーザー登録をしなくても、そのままご利用できる可能性があります。<br>
<a href="userlogin.php">ログイン画面</a>にてご確認ください。
<?php
	}
?>
</div>

<?php
}
?>

</div>
<br clear="both">
<br>
<?php
	// お知らせを表示する
	require_once(TODOTASK_VIEW_DIR.'/grp/notice.inc.php');

	// フッター
	include_once(TODOTASK_VIEW_DIR.'/common/footer.inc.php');

?>

==> todotask2.0.2.zip: todotask2/app/views/grp/list.php <==
<?php
	// ページ描画
	// ヘッダ
	require_once(TODOTASK_VIEW_DIR.'/common/header.inc.php');

	$aryGrpList = $this->aryGrpList;

	$task_state = "";
	if ($this->mode==GRP_CLASS_MODE_MYGRP) {
		$task_state = "参加グループ";
		$mytag_img = "mytask.png";
		$alltag_img = "alltask2.png";
	} else {
		$task_state = "グループ一覧";
		$mytag_img = "mytask2.png";
		$alltag_img = "alltask.png";
	}

	// タスクのリンクを作成する
	function fSetTaskList($group_no,$group_name,$group_note,$aryassent,$aryview,$upd,$group_prio) {
		if ( $group_no =="" ) {
			return true;
		}
?>
		<p><a href="./tasklist.php?group_no=<?php echo $group_no; ?>"><span class="grptitle">
		■ <?php echo $group_name; ?></span></a>
		(<?php echo $upd; ?>)
		グループ重要度：<?php echo $group_prio;?>
		<small><?php echo $aryview;?> / <?php echo $aryassent; ?></small><br>
		<span class="grpnote">
		<?php echo $group_note;?>
		<br></span></p>		

<?php
	}
?>





<div style="margin:auto;padding:auto;text-align:center;">
<img src="./images/whytodotask.png" alt="タスクや障害を詳細に分解しリストにすることはあなたを目標から遠ざけないただひとつの吸引力！" border="0">
</div>
<div class="noticediv">
このサービスはやるべきこと(TO-DO)や課せられた仕事(TASK)を共有し管理するのに便利です。<br>
備忘録や業務の進捗管理などに使ってみてください。
詳しくは<big><a href="<?php echo INFO_HOWTOUSE_PAGE; ?>" target="_blank">使用ガイド</a></big>をごらんください。<br>
TODOTASKはオープンソースプロジェクトです。プロジェクト参加者募集しております。
</div>
<br clear="both">


<div style="border-bottom:solid 3px #000000;margin-bottom:10px;">
<a href="./index.php?mode=<?php echo GRP_CLASS_MODE_MYGRP;?>">
<img src="./images/<?php echo $mytag_img; ?>" alt="自分のグループのみ表示する" border="0" align="left"></a>
<a href="./index.php?mode=<?php echo GRP_CLASS_MODE_LIST;?>">
<img src="./images/<?php echo $alltag_img; ?>" alt="すべてのグループを表示する" border="0"></a>
</div>


<?php
if ($this->mode==GRP_CLASS_MODE_MYGRP) {
?>
<a href="./grpmake.php"><img src="./images/btn_makegroup.png" alt="新規グループの作成" border="0" align="right"></a><br><br>
<?php
}
?>

<h4><?php echo $task_state; ?></h4>
<div class="grplist">
<?php
	// グループリンクの表示
	for( $i=0; $i < count($aryGrpList); $i++ ) {
		// タスクのリンク
		fSetTaskList($aryGrpList[$i]["group_no"],
					$aryGrpList[$i]["group_name"],
					$aryGrpList[$i]["group_note"],
					$aryGrpList[$i]["assent"],
					$aryGrpList[$i]["view"],
					$aryGrpList[$i]["upd"],
					$aryGrpList[$i]["group_prio"]);
	} 

	if (count($aryGrpList)==0) {
		echo "<br><big>参加グループがないかログインしていません。</big><br><br>" .
				"<a href=index.php?mode=1>（All Task）タグ</a>から既存のグループを探し参加するか自分の<a href=grpmake.php>グループを作成</a>してください。<br>" .
				"グループの作成や参加には<a href=userlogin.php>ログイン</a>が必要です。<br>" .
				"まだユーザー登録が済んでいない方は<a href=usermst.php>ユーザー登録</a>を行ってください。";
	}


// 改ページの表示
?>
	</div><br>
	<div class="pagelink">
	<?php echo $this->pagelink; ?>
	</div><br><br>



<div style="text-align:right;width:100%;">
<?php
if ($this->user_id == "") {
?>
<div style="width:450px;border:solid #eeddee 2px;padding:10px;background-color:#ffffff;right:0px;float:right;">
<a href="./usermst.php"><img src="./images/btn_signup.png" alt="新規ユーザー登録" border="0"></a><br>

ログインされていません。このサービスを利用するにはユーザー登録後にログインをしていただく必要があります。<br>
ユーザー登録は上のボタンをクリックして必要な情報を入力してください。<br>

<?php
	// 外部認証が利用できる場合
	if (JUGEM_AUTHFLG||HATENA_AUTHFLG||LIVEDOOR_AUTHFLG) {
?>
<hr size="1">
<big>外部認証が利用できるように設定されています。</big><br>
Hatena,LiveDoor,Jugemなど他のサービスでログインしている場合ユーザー登録をしなくても、そのままご利用できる可能性があります。<br>
<a href="userlogin.php">ログイン画面</a>にてご確認ください。
<?php
	}
?>
</div>

<?php
}
?>

</div>
<br clear="both">
<br>
<?php
	// お知らせを表示する
	require_once(TODOTASK_VIEW_DIR.'/grp/notice.inc.php');

	// フッター
	include_once(TODOTASK_VIEW_DIR.'/common/footer.inc.php');

?>
